==> use-media-query-1.0.0.tgz: package/esm/useMediaQuery.js <==
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import * as React from "react";
var useIsomorphicLayoutEffect = typeof window !== "undefined" ? React.useLayoutEffect : React.useEffect;
var isSupported = typeof window !== "undefined" && "matchMedia" in window;
var useMediaQuery = function (query) {
    var queries = Array.isArray(query) ? query : [query];
    var queriesKey = queries.join();
    var _a = React.useState(Array(queries.length).fill(false)), matches = _a[0], setMatches = _a[1];
    useIsomorphicLayoutEffect(function () {
        if (!isSupported) {
            // eslint-disable-next-line no-console
            console.error([
                "UtilityJS: useMediaQuery relies on the `window.matchMedia` API.",
                "Since it is not supported in your browser, we are returning `false`."
            ].join("\n"));
            return;
        }
        var mediaQueries = queries.map(function (query) { return matchMedia(query); });
        // Initial matching
        setMatches(mediaQueries.map(function (mediaQuery) { return mediaQuery.matches; }));
        var unsubscribed = false;
        var changeHandlers = mediaQueries.map(function (mediaQuery) {
            var changeHandler = function (event) {
                if (unsubscribed)
                    return;
                var isMatched = event.matches;
                var queryIndex = mediaQueries.findIndex(function (mediaQuery) { return mediaQuery.media === event.media; });
                setMatches(function (prevMatches) {
                    var clone = __spreadArray([], prevMatches, true);
                    clone[queryIndex] = isMatched;
                    return clone;
                });
            };
            mediaQuery.addEventListener("change", changeHandler);
            return changeHandler;
        });
        return function () {
            unsubscribed = true;
            mediaQueries.forEach(function (mediaQuery, index) {
                mediaQuery.removeEventListener("change", changeHandlers[index]);
            });
        };
    }, [queriesKey]);
    return matches;
};
export default useMediaQuery;

==> use-media-query-1.0.1.tgz: package/esm/useMediaQuery.js <==
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import * as React from "react";
var useIsomorphicLayoutEffect = typeof window !== "undefined" ? React.useLayoutEffect : React.useEffect;
var isSupported = typeof window !== "undefined" && "matchMedia" in window;
var useMediaQuery = function (query) {
    var queries = Array.isArray(query) ? query : [query];
    var queriesKey = queries.join();
    var _a = React.useState(Array(queries.length).fill(false)), matches = _a[0], setMatches = _a[1];
    useIsomorphicLayoutEffect(function () {
        if (!isSupported) {
            // eslint-disable-next-line no-console
            console.error([
                "[@utilityjs/use-media-query]: useMediaQuery relies on the `window.matchMedia` API.",
                "Since it is not supported in your browser, we are returning `false`."
            ].join("\n"));
            return;
        }
        var mediaQueries = queries.map(function (query) { return matchMedia(query); });
        // Initial matching
        setMatches(mediaQueries.map(function (mediaQuery) { return mediaQuery.matches; }));
        var unsubscribed = false;
        var changeHandlers = mediaQueries.map(function (mediaQuery) {
            var changeHandler = function (event) {
                if (unsubscribed)
                    return;
                var isMatched = event.matches;
                var queryIndex = mediaQueries.findIndex(function (mediaQuery) { return mediaQuery.media === event.media; });
                setMatches(function (prevMatches) {
                    var clone = __spreadArray([], prevMatches, true);
                    clone[queryIndex] = isMatched;
                    return clone;
                });
            };
            mediaQuery.addEventListener("change", changeHandler);
            return changeHandler;
        });
        return function () {
            unsubscribed = true;
            mediaQueries.forEach(function (mediaQuery, index) {
                mediaQuery.removeEventListener("change", changeHandlers[index]);
            });
        };
    }, [queriesKey]);
    return matches;
};
export default useMediaQuery;
